@@ -1,4 +1,6 @@
 """
+$Id$
+
 Copyright (C) 2008 Aaron Diep <ahkdiep@gmail.com>
 
 This file is part of Python-Ctags.
@@ -18,7 +20,7 @@ along with Python-Ctags.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 
-from _readtags import TagEntry, CTags
+from ._readtags import TagEntry, CTags
 __all__ = ['TagEntry', 'CTags']
 
 # sortType
